@@ -4,6 +4,9 @@ if [ "$IS_CONTAINER" != "" ]; then
   go vet "${@}"
 else
   docker run --rm \
+    --env GO111MODULE="$GO111MODULE" \
+    --env GOFLAGS="$GOFLAGS" \
+    --env GOPROXY="$GOPROXY" \
     --env IS_CONTAINER=TRUE \
     --volume "${PWD}:/go/src/github.com/openshift/${REPO_NAME}:z" \
     --workdir "/go/src/github.com/openshift/${REPO_NAME}" \
